# Motor

OpenMV verfügt über IO-Ports und kann verschiedene Motoren antreiben.

## Schrittmotor

### Was ist ein Schrittmotor?

Der Schrittmotor ist ein Steuermotor mit offenem Regelkreis, der elektrische
Impulssignale in Winkelverschiebung oder lineare Verschiebung umwandelt. Er ist
das wichtigste ausführende Element in modernen digitalen
Programmsteuerungssystemen und wird häufig verwendet.

Zum Beispiel 3D-Drucker und Roboterarme.

### Schrittmotor-Treiberplatine

Viele Chips und Module können Schrittmotoren steuern. Wir verwenden ein sehr
einfaches Modul, EasyDriver.

Vereinfacht ausgedrückt wird die Richtung durch dir gesteuert, und wenn Schritt
ein Impuls gegeben wird, bewegt sich der Motor um einen Schritt.

![](/assets/06-07-001.jpg)

### Verbinden

![](/assets/06-07-002.jpg)

## Modul installieren

[Modulcode finden Sie in diesem
Link](http://book.openmv.cc/module/write-module-motor.html)

Speichern Sie den Code dieser Klasse als stepper.py-Datei und legen Sie ihn im
Stammverzeichnis von OpenMV ab.

## Code

```python
# 步进电机控制 - By: 小智智- 周日 4月 2 2017

from pyb import Pin

from stepper import Stepper

import time

step_pin = Pin('P0')
dir_pin = Pin('P1')

my_stepper = Stepper(step_pin,dir_pin)

print("relative angle move test begin:", my_stepper.read_pos())
my_stepper.rel_angle(180)#相对角度控制
print("relative angle move test end:", my_stepper.read_pos())

time.sleep_ms(1000)

print("steps angle move test end:", my_stepper.read_pos())
my_stepper.steps(-400)#步进脉冲控制
print("steps angle move test end:", my_stepper.read_pos())

time.sleep_ms(1000)

print("absolute angle move test begin:", my_stepper.read_pos())
my_stepper.abs_angle(0)#绝对角度控制
print("absolute angle move test end:", my_stepper.read_pos())

time.sleep_ms(1000)
```

## Gleichstrommotor

#### Tutorial 26-Motor-Erweiterte Version steuert Gleichstrommotor: [https://singtown.com/video](https://singtown.com/video)

### Was ist ein Gleichstrommotor?

Die Drehzahl eines Gleichstrommotors ist direkt proportional zur Spannung.

### Treiberplatine

Viele Treiberplatinen können Gleichstrommotoren antreiben, hier verwenden wir
TB6612FNG, Dual-H-Brücke.

![](/assets/06-07-003.jpg)

### Verbinden

![](/assets/06-07-004.jpg)

### Code

```python
待添加
```

## Lenkgetriebe

OpenMV2 verfügt über zwei Servo-Pins, P7 und P8

OpenMV3 verfügt über drei Servo-Pins, P7, P8, P9

### Verbinden

![](/assets/06-07-005.jpg)

### Stromversorgung prüfen

Das Servo ist ein Hochstromgerät und muss über eine externe Stromversorgung
verfügen (geregelte Stromversorgung, Lithiumbatterie...). USB kann das Servo
nicht mit Strom versorgen!

### Code

```python
# Servo Control Example
#
# This example shows how to use your OpenMV Cam to control servos.

import time
from pyb import Servo

s1 = Servo(1) # P7
s2 = Servo(2) # P8
#s3 = Servo(3) # P9 Only for OpenMV3 M7
while(True):
    for i in range(-90,90):
        s1.angle(i)
        s2.angle(i)
        time.sleep_ms(10)
    for i in range(90,-90):
        s1.angle(i)
        s2.angle(i)
        time.sleep_ms(10)
```

## PCA9685 verbindet mehrere Servos

Baby-Link:\
[https://singtown.com/product/49277](https://singtown.com/product/49277)

#### Video-Tutorial 25-pca9685 steuert mehrere Servos:[https://singtown.com/learn/50057/](https://singtown.com/learn/50057/)



Das PCA9685-Modul kann mit nur 2 Pins (12C-Protokoll) 16 PWM-Kanäle steuern,
also 16 Servos oder 16 LED-Leuchten. Sie können sogar 62 Module anschließen und
trotzdem nur 2 Pins zur Steuerung von 992 PWMs verwenden!

Verbinden

![](/assets/06-07-006-01.jpg)

Code

![](/assets/06-07-007.jpg)

Klicken Sie zum Ausführen

